
#=============================================================================
# Overview of build options:
#
# End of build options
#-----------------------------------------------------------------------------

##trace

# force single job compilation
#%%define _smp_mflags -j1

%global debug_package    %{nil}
%global _lto_cflags      %{nil}

%global with_32bit       1
%global wineversion      9.4

%global gitdate          20220710
%global commit           56c3e9da95b467f1f64ba069864c35762251a734
%global shortcommit      %(c=%{commit}; echo ${c:0:7})

%global version          1.2.0
%global release          9

# set this to "1" if building a git/beta/rc release
%global beta_or_rc       0


#=============================================================================
# general
#-----------------------------------------------------------------------------
Name:           pipewire-wineasio
Version:        %{version}
%if %{beta_or_rc}
Release:        0.%{release}.%{gitdate}.git%{shortcommit}%{?dist}
%else
Release:        %{release}%{?dist}
%endif
Summary:        ASIO to Pipewire's JACK driver for WINE
License:        LGPLv2.1
URL:            https://github.com/wineasio/wineasio
%if %{beta_or_rc}
Source0:        https://github.com/wineasio/wineasio/archive/{commit}/wineasio-%{version}-git%{shortcommit}.tar.gz
%else
Source0:        https://github.com/wineasio/wineasio/archive/%{version}/wineasio-%{version}.tar.gz
%endif
#Patch0:         c4bcac2a594b2d3ef3bc64c39b20d05b5e4ce87f.patch
# https://github.com/wineasio/wineasio
# git clone --recursive
# don't git submodule update --init
# ~/bin/git-archive-all.sh --format=tar.gz --prefix=wineasio-1.1.0/ -o ../wineasio-1.1.0.tar.gz
BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  pipewire-jack-audio-connection-kit-devel
BuildRequires:  wine-devel = %{wineversion}
%if %{with_32bit}
BuildRequires:  glibc-devel(x86-32)
BuildRequires:  pipewire-jack-audio-connection-kit-devel(x86-32)
BuildRequires:  pkgconf(x86-32)
BuildRequires:  pkgconf-pkg-config(x86-32)
BuildRequires:  wine-devel(x86-32) = %{wineversion}
%endif
BuildArch:      x86_64
Requires:       pipewire-jack-audio-connection-kit
Requires:       wine = %{wineversion}
#Requires:       wine
Requires:       python3-qt5
%if %{with_32bit}
Requires:       pipewire-jack-audio-connection-kit(x86-32)
Requires:       wine(x86-32) = %{wineversion}
Conflicts:      wineasio(x86-32)
%endif
Conflicts:      wineasio

%description
WineASIO provides an ASIO to JACK driver for WINE. ASIO is the most common
Windows low-latency driver, so is commonly used in audio workstation programs.
You can, for example, use with FLStudio under GNU/Linux systems (together
with JACK).

This version is built against Pipewire's JACK implementation.

#%%package gui
#Summary:        GUI for %%{name}
#Requires:       %%{name}

#%%description gui
#GUI for %%{name}


#=============================================================================
# prep
#-----------------------------------------------------------------------------
%prep
%if %{beta_or_rc}
%autosetup -p1 -n wineasio
%else
%autosetup -p1 -n wineasio-%{version}
%endif


#=============================================================================
# build
#-----------------------------------------------------------------------------
%build
%make_build 64

%if %{with_32bit}
sed -i -e's|$(shell pkg-config --libs jack)|-L/usr/lib/pipewire-0.3/jack -ljack -ljackserver|' Makefile.mk
%make_build 32
%endif


#=============================================================================
# check
#-----------------------------------------------------------------------------
%check
# there are no tests


#=============================================================================
# install
#-----------------------------------------------------------------------------
%install
# create lib dirs
install -d -m0755 %{buildroot}%{_libdir}/wine/x86_64-windows
%if %{with_32bit}
install -d -m0755 %{buildroot}%{_prefix}/lib/wine/i386-windows
%endif

# install wine-register
install -D -m 0755 wineasio-register %{buildroot}%{_bindir}/wineasio-register

# install libs
install -D -m 0755 build64/wineasio64.dll %{buildroot}%{_libdir}/wine/x86_64-windows/wineasio64.dll
install -D -m 0755 build64/wineasio64.dll.so %{buildroot}%{_libdir}/wine/x86_64-unix/wineasio64.dll.so

%if %{with_32bit}
install -D -m 0755 build32/wineasio32.dll %{buildroot}%{_prefix}/lib/wine/i386-windows/wineasio32.dll
install -D -m 0755 build32/wineasio32.dll.so %{buildroot}%{_prefix}/lib/wine/i386-unix/wineasio32.dll.so
%endif

# install gui
pushd gui
%make_install
popd


#=============================================================================
# files
#-----------------------------------------------------------------------------
%files
%defattr(-,root,root)
%license COPYING.LIB COPYING.GUI
%doc README.md
%attr(0755,root,root)        %{_bindir}/wineasio-register
%attr(0755,root,root)        %{_bindir}/wineasio-settings
%attr(0755,root,root)  %dir  %{_datadir}/wineasio
%attr(0644,root,root)        %{_datadir}/wineasio/*.py
%attr(0755,root,root)        %{_libdir}/wine/x86_64-windows/wineasio64.dll
%attr(0755,root,root)        %{_libdir}/wine/x86_64-unix/wineasio64.dll.so
%if %{with_32bit}
%attr(0755,root,root)        %{_prefix}/lib/wine/i386-windows/wineasio32.dll
%attr(0755,root,root)        %{_prefix}/lib/wine/i386-unix/wineasio32.dll.so
%endif


#=============================================================================
# post
#-----------------------------------------------------------------------------
%post
/sbin/ldconfig


#=============================================================================
# postun
#-----------------------------------------------------------------------------
%postun
/sbin/ldconfig


#=============================================================================
# changelog
#-----------------------------------------------------------------------------
%changelog
* Fri Nov 15 2024 Patrick Laimbock <patrick@laimbock.com> - 1.2.0-9
- rebuild against wine-9.4 on F41

* Sat Oct 26 2024 Patrick Laimbock <patrick@laimbock.com> - 1.2.0-8
- rebuild against wine-9.20

* Mon May 06 2024 Patrick Laimbock <patrick@laimbock.com> - 1.2.0-7
- since requiring a specific wine version makes up/downgrading difficult
- let's revert back to requiring 9.4 or later

* Sun May 05 2024 Patrick Laimbock <patrick@laimbock.com> - 1.2.0-6
- build/require wine-9.8 from the wine-tkg-dev copr

* Mon Apr 29 2024 Patrick Laimbock <patrick@laimbock.com> - 1.2.0-5
- rebuild against wine-9.4

* Sat Feb 03 2024 Patrick Laimbock <patrick@laimbock.com> - 1.2.0-4
- rebuild against wine-9.1

* Sat Dec 16 2023 Patrick Laimbock <patrick@laimbock.com> - 1.2.0-3
- rebuild against wine-9.0(-rc2)

* Sun Oct 29 2023 Patrick Laimbock <patrick@laimbock.com> - 1.2.0-2
- test build: require wine >= 8.4 because of an Ableton issue with 8.18

* Sun Oct 29 2023 Patrick Laimbock <patrick@laimbock.com> - 1.2.0-1
- update to version 1.2.0
- include the gui in the main package

* Mon May 29 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-21
- rebuild against wine-8.9.1 from the wine-tkg copr

* Mon May 15 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-20
- rebuild against wine-8.8

* Sat Apr 29 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-19
- rebuild against wine-8.7

* Wed Apr 19 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-18
- rebuild against wine-8.6

* Tue Apr 04 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-17
- rebuild against wine-8.5

* Thu Mar 30 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-16
- rebuild against wine-8.4

* Thu Feb 23 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-15
- rebuild against wine-8.2

* Wed Jan 25 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-14
- rebuild against wine-8.0
- rebuild against latest pipewire

* Sun Jan 22 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-13
- rebuild against wine-8.0rc5

* Thu Jan 12 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-12
- rebuild against wine-8.0rc4
- disable patch

* Thu Jan 12 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-11
- add patch from https://github.com/TobiasKozel/wineasio/commit/c4bcac2a594b2d3ef3bc64c39b20d05b5e4ce87f

* Mon Jan 02 2023 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-10
- build against wine-8.0

* Thu Nov 03 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-9
- build against wine-7.20

* Sat Oct 01 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-8
- build against wine-7.18
=
* Sat Sep 10 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-7
- build against wine-7.17

* Sun Aug 28 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-6
- build against wine-7.16

* Sun Aug 14 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-5
- build against wine-7.15

* Sat Jul 30 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-4
- build against wine-7.14

* Sun Jul 10 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-3
- build against wine-7.13

* Sun Jul 10 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-2
- build against wine-7.12
- disable LTO

* Sun Feb 27 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-1
- update to version 1.1.0
- build against wine-7.3

* Sat Jan 01 2022 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-0.3
- build against wine-7.0rc3

* Sun Dec 05 2021 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-0.2
- build against wine-6.23

* Thu Nov 25 2021 Patrick Laimbock <patrick@laimbock.com> - 1.1.0-0.1
- update to version 1.1.0
- build against wine-6.22

* Thu Oct 07 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.9
- build against wine-6.18
- build against pipewire-0.3.38

* Sat Sep 11 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.8
- build against wine-6.17
- build against pipewire-0.3.35

* Sat Aug 28 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.7
- build against wine-6.16
- build against pipewire-0.3.34

* Sat Aug 14 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.6
- build against wine-6.15
- build against pipewire-0.3.33

* Sun Aug 01 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.5
- build against wine-6.14

* Mon Jul 26 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.4
- enable wineasio-pr-17.patch again as disabling it did not fix anything

* Mon Jul 26 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.4
- use the proper wine locations to install the dll.so to

* Mon Jul 26 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.3
- disable wineasio-pr-17.patch

* Mon Jul 26 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.2
- fix 32bit Requires (remove regular JACK)

* Mon Jul 26 2021 Patrick Laimbock <patrick@laimbock.com> - 1.0.1-0.1
- wineasio built against Pipewire's JACK implementation

